@@ -64,15 +64,6 @@ def _create_argparser() -> argparse.ArgumentParser:
         action=ArgActionStoreTrue,
     )
 
-    run_conf.add_argument(
-        "--resume",
-        default=False,
-        action=ArgActionStoreTrue,
-        help="Whether to resume training or inference from a checkpoint. Specify a --run-id to use this option. "
-             "If set, the training code loads an already trained model to initialize the neural network "
-             "before resuming training. This option is only valid when the models exist, and have the same "
-             "behavior names as the current agents in your scene.",
-    )
     run_conf.add_argument(
         "--force",
         default=False,
@@ -155,6 +146,21 @@ def _create_argparser() -> argparse.ArgumentParser:
         help="Total capacity of memory, should be > batch_size",
     )
 
+    run_conf.add_argument(
+        "--resume",
+        default=False,
+        action=ArgActionStoreTrue,
+        help="resumes the training from last saved checkpoint"
+    )
+
+    run_conf.add_argument(
+        "--clear_memory",
+        default=False,
+        action=ArgActionStoreTrue,
+        help="On resuming, the memory will be cleared and actions would be "
+             "sampled from the neural network, if neural network is not trained "
+             "yet, then actions would sample from action_space",
+    )
     env_desc = "The arguments are used to configure the environment."
     env_conf = argparser.add_argument_group(title="Environment Configuration",
                                             description=env_desc)
@@ -218,10 +224,18 @@ def _create_argparser() -> argparse.ArgumentParser:
     )
     env_conf.add_argument(
         "--goal_distance",
-        default=50,
+        default=10,
         help="Distance to goal from current location",
         action=ArgAction,
     )
+
+    env_conf.add_argument(
+        "--traffic_vehicles",
+        default=0,
+        help="Number of traffic vehicles",
+        action=ArgAction,
+    )
+
     env_conf.add_argument(
         "--agent_car_physics",
         default=0,
@@ -259,7 +273,12 @@ def _create_argparser() -> argparse.ArgumentParser:
         help="Shortest path length delta multiplier",
         action=ArgAction,
     )
-
+    env_conf.add_argument(
+        "--save_actions",
+        default=False,
+        action=ArgActionStoreTrue,
+        help="Save the actions vector at every step",
+    )
     env_conf.add_argument(
         "--save_visual_obs",
         default=False,
@@ -272,6 +291,13 @@ def _create_argparser() -> argparse.ArgumentParser:
         action=ArgActionStoreTrue,
         help="Save the vector observations at every step",
     )
+    env_conf.add_argument(
+        "--show_visual",
+        default=False,
+        action=ArgActionStoreTrue,
+        help="Show visual obs window",
+    )
+
 
     dev_desc = "The arguments are used by developers to benchmark and debug navsim API"
     dev_conf = argparser.add_argument_group(title="Developer Configuration",
