@@ -31,6 +31,9 @@ from mlagents_envs.side_channel.float_properties_channel import \
 
 logger = get_logger(__name__)
 
+
+#TODO: -showVisualObservations
+
 try:
     from cv2 import imwrite as imwrite
 
@@ -96,6 +99,7 @@ class NavSimGymEnv(UnityToGymWrapper):
         elif self.obs_mode == 1:
             env_config["save_vector_obs"] = False
 
+        self.save_actions = env_config.get("save_actions", False)
         self.save_visual_obs = env_config.get("save_visual_obs", False)
         self.save_vector_obs = env_config.get("save_vector_obs", False)
 
@@ -145,7 +149,8 @@ class NavSimGymEnv(UnityToGymWrapper):
         env_sfp("goalSelectionIndex", float(self.env_config.get('goal', 0)))
         env_sfp("agentCarPhysics",
                 float(self.env_config.get('agent_car_physics', 0)))
-        env_sfp("goalDistance", float(self.env_config.get('goal_distance', 50)))
+        env_sfp("goalDistance", float(self.env_config.get('goal_distance', 10)))
+        env_sfp("numberOfTrafficVehicles", float(self.env_config.get('traffic_vehicles', 0)))
 
         env_path = self.env_config.get('env_path')
         env_path = None if env_path is None else str(Path(env_path).resolve())
@@ -161,15 +166,18 @@ class NavSimGymEnv(UnityToGymWrapper):
                     self.env_config.get('log_folder', './env_log')).resolve()
                 log_folder.mkdir(parents=True, exist_ok=True)
                 ad_args = [
-                    f"-force-device-index {self.env_config.get('env_gpu_id', 0)}",
-                    f"-observationWidth {self.env_config.get('obs_width', 256)}",
-                    f"-observationHeight {self.env_config.get('obs_height', 256)}"
+                    "-force-device-index",f"{self.env_config.get('env_gpu_id', 0)}",
+                    "-observationWidth",f"{self.env_config.get('obs_width', 256)}",
+                    "-observationHeight",f"{self.env_config.get('obs_height', 256)}",
+                    "-fastForward",f"{self.start_from_episode - 1}",
+                    "-showVisualObservations" if self.env_config.get('show_visual',False) else "",
+                    "-saveStepLog" if self.debug else ""
                 ]
                 uenv = UnityEnvironment(file_name=env_path,
                                         log_folder=str(log_folder),
                                         seed=seed,
                                         timeout_wait=self.env_config.get(
-                                            'timeout', 600),
+                                            'timeout', 600) + (0.5*(self.start_from_episode - 1)),
                                         worker_id=self._navsim_worker_id,
                                         base_port=self._navsim_base_port,
                                         no_graphics=False,
@@ -182,7 +190,8 @@ class NavSimGymEnv(UnityToGymWrapper):
                 self._navsim_base_port += 1
             else:
                 logger.info(f"Created UnityEnvironment at port "
-                            f"{self._navsim_base_port + self._navsim_worker_id}")
+                            f"{self._navsim_base_port + self._navsim_worker_id}"
+                            f" to start from episode {self.start_from_episode}")
                 break
 
         super().__init__(unity_env=uenv,
@@ -193,17 +202,17 @@ class NavSimGymEnv(UnityToGymWrapper):
                          )
 
         # TODO: Once the environment has capability to start from an episode, then remove this
-        if self.start_from_episode > 1:
-            logger.info(f'jumping to episode {self.start_from_episode}')
-        for i in range(1, self.start_from_episode):
-            self.reset()
-            logger.info(f'skipping episode {self.e_num}')
+        #if self.start_from_episode > 1:
+        #    logger.info(f'jumping to episode {self.start_from_episode}')
+        #for i in range(1, self.start_from_episode):
+        #    self.reset()
+        #    logger.info(f'skipping episode {self.e_num}')
 
         # TODO: the filenames should be prefixed with specific id of this instance of env
 
-        if self.save_visual_obs or self.save_vector_obs:
-            # TODO: Read the file upto start_episode and purge the records
-            self.actions_file = log_folder / 'actions.csv'
+        # TODO: Read the file upto start_episode and purge the records
+        self.actions_file = log_folder / 'actions.csv'
+        if self.save_actions:
             if (self.start_from_episode == 1) or (
                     self.actions_file.exists() == False):
                 self.actions_file = self.actions_file.open(mode='w')
@@ -263,25 +272,22 @@ class NavSimGymEnv(UnityToGymWrapper):
 
     def reset(self) -> Union[List[np.ndarray], np.ndarray]:
         result = super().reset()
-
-        self.e_num += 1
         self.s_num = 0
-        if self.e_num >= self.start_from_episode:
-            self.obs = result
-            self.spl_start = self.spl_current = self.get_shortest_path_length()
-            self.save_obs(self.obs)
+        self.e_num += 1 if self.e_num else self.start_from_episode
+        self.obs = result
+        self.spl_start = self.spl_current = self.get_shortest_path_length()
+        self.save_obs(self.obs)
         return result
 
     def step(self, action: List[Any]) -> GymStepResult:
         s_, r, episode_done, info = super().step(action)
         self.obs = s_
         self.s_num += 1
-        if self.save_vector_obs or self.save_visual_obs:
-            self.actions_writer.writerow(
-                [self.e_num, self.s_num] + list(action))
-            self.actions_file.flush()
         self.spl_current = self.get_shortest_path_length()
         self.save_obs(self.obs)
+        if self.save_actions:
+            self.actions_writer.writerow([self.e_num, self.s_num] + list(action))
+            self.actions_file.flush()
         return s_, r, episode_done, info
 
     #def close(self):
