@@ -1,22 +1,10 @@
 from pathlib import Path
 from typing import Optional, List, Set
 
-import attr
 import navsim
-from .util import ObjDict
+from .util.dict import ObjDict
 from .cli_utils import argparser, non_default_args
-
-
-@attr.s(auto_attribs=True)
-class RunConfig:
-    """
-    Configuration for running in general
-    """
-    run_id: str = argparser.get_default("run_id")
-    train = argparser.get_default("train")
-    debug = argparser.get_default("num_envs")
-    resume = argparser.get_default("resume")
-    seed = argparser.get_default("force")
+from navsim.executor.navsim_executor import Executor
 
 
 def main():
@@ -24,26 +12,19 @@ def main():
     TODO: Implement configuration checks
     :return:
     """
-    print(f'===================================')
-    print(f'Navsim Version {navsim.__version__}')
-    print(f'===================================')
+    print(f'=========================================')
+    print(f'Navsim Python API Version {navsim.__version__}')
+    print(f'========================================')
     args = ObjDict(vars(argparser.parse_args()))
     print('arguments passed:')
     print(non_default_args)
+    print("Passed + default arguments:")
+    print(args.to_yaml())
 
-    run_base_folder = Path(args.run_id)
-    run_base_folder_str = str(run_base_folder.resolve())
-    if args.resume and run_base_folder.is_dir():
-        # TODO: Logic for resume here
-        pass
-    # else just start fresh
-    else:
-        args.resume = False
-        print("Resume set to True, but nothing to resume from, starting fresh")
-        run_base_folder.mkdir(parents=True, exist_ok=True)
+    # lets get the arguments
 
     env_conf = ObjDict({
-        "log_folder": str((run_base_folder / "env_log").resolve()),
+        "log_folder": str(run_base_folder / "env_log"),
         "env_path": args["env_path"],
         "worker_id": 0,
         "base_port": 5005,
@@ -57,6 +38,7 @@ def main():
         "task": int(args["task"]),
         "goal": int(args["goal"]),
         "goal_distance": int(args["goal_distance"]),
+        "traffic_vehicles": int(args["traffic_vehicles"]),
         "agent_car_physics": int(args["agent_car_physics"]),
         "reward_for_goal": float(args["reward_for_goal"]),
         "reward_for_no_viable_path": float(args["reward_for_no_viable_path"]),
@@ -65,15 +47,17 @@ def main():
         "reward_spl_delta_mul": float(args["reward_spl_delta_mul"]),
         "env_gpu_id": int(args["env_gpu_id"]),
         "debug": args["debug"],
+        "save_actions": args["save_actions"],
         "save_vector_obs": args["save_vector_obs"],
-        "save_visual_obs": args["save_visual_obs"]
+        "save_visual_obs": args["save_visual_obs"],
+        "show_visual": args["show_visual"]
     })
 
     run_conf = ObjDict({
         "run_id": args["run_id"],
-        "env":'navsim-v0',
+        "env": 'navsim-v0',
         "agent_gpu_id": int(args["agent_gpu_id"]),
-        "num_workers" : 1,
+        "num_workers": 1,
         "episode_max_steps": int(args["episode_max_steps"]),
         "total_episodes": int(args["total_episodes"]),
         "seed": int(args["seed"]),
@@ -84,27 +68,43 @@ def main():
         "batch_size": int(args["batch_size"]),
         "checkpoint_interval": int(args["checkpoint_interval"]),
         "train_interval": int(args["train_interval"]),
-        "mem_backend": args["mem_backend"]
+        "mem_backend": args["mem_backend"],
+        "clear_memory": args["clear_memory"],
+        "log_level": "DEBUG" if args.debug else "INFO",
+        "framework": "torch"
     })
 
+    run_base_folder = Path(args.run_id).resolve()
+
+    if args.resume:
+        if run_base_folder.exists():
+            # TODO: Logic for resume here
+            pass
+
+        else:  # else just start fresh
+            args.resume = False
+            print(
+                "Resume set to True, but nothing to resume from, starting fresh")
+
+    # start fresh logic
+    if not args.resume:
+        run_base_folder.mkdir(parents=True, exist_ok=True)
+
+
+
     if args["rl_backend"] == "rllib":
         import ray.rllib.agents.ppo as ppo
         conf = ppo.DEFAULT_CONFIG.copy()
-        if args.debug:
-            conf["log_level"] = "DEBUG"
-        else:
-            conf["log_level"] = "INFO"
-
-        conf["framework"] = "torch"
+        # copy from run_config to conf
+        for key in run_conf:
+            if key in conf:
+                conf[key] = run_conf[key]
         conf["ignore_worker_failures"] = True
     else:
         conf = ObjDict()
         conf['run_config'] = run_conf
-
     conf['env_config'] = env_conf
 
-    print("Passed arguments + defaults:")
-    print(args.to_yaml())
     # print("Final Configuration:")
     # print(conf.to_yaml())
 
@@ -118,7 +118,7 @@ def main():
             config=conf,
             name=run_conf.run_id,
             resume=args.resume,
-            local_dir=run_base_folder_str,
+            local_dir=str(run_base_folder),
             stop={"episodes_total": run_conf.total_episodes},
             checkpoint_freq=run_conf.checkpoint_interval,
             checkpoint_at_end=True
@@ -141,8 +141,12 @@ def main():
         # then overwrite with the args passed
         # TODO: Optimize this with respect to above arg/config setting
         if args.resume and run_base_folder.is_dir():
-            conf = ObjDict().load_from_json_file(f"{run_base_folder_str}/conf"
-                                                 f".json")
+            conf = ObjDict().load_from_json_file(
+                str(run_base_folder / "conf.json"))
+            if ("agent_car_physics" in non_default_args) and int(
+                    conf["env_config"]["agent_car_physics"]) != int(
+                    args["agent_car_physics"]):
+                non_default_args["clear_memory"] = True
             for passed_arg in non_default_args:
                 if passed_arg in conf["env_config"]:
                     conf["env_config"][passed_arg] = args[passed_arg]
@@ -160,7 +164,8 @@ def main():
             for arg in ["env_gpu_id", "seed", "timeout", "base_port",
                         "obs_mode", "obs_height", "obs_width",
                         "segmentation_mode", "episode_max_steps", "task",
-                        "goal", "goal_distance", "agent_car_physics"]:
+                        "goal", "goal_distance", "traffic_vehicles",
+                        "agent_car_physics"]:
                 conf["env_config"][arg] = int(conf["env_config"][arg])
             for arg in ["reward_for_goal",
                         "reward_for_no_viable_path",
@@ -168,9 +173,8 @@ def main():
                         "reward_spl_delta_mul"]:
                 conf["env_config"][arg] = float(conf["env_config"][arg])
 
-        executor = navsim.executor.Executor(run_id=args["run_id"],
-                                   resume=args["resume"],
-                                   conf=conf)
+        executor = Executor(resume=args["resume"],
+                            conf=conf)
         executor.execute()
         print("training finished")
 
